@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2008 Zope Corporation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -11,7 +11,10 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""File content component"""
+"""File content component
+
+$Id: file.py 90989 2008-09-09 09:37:27Z nadako $
+"""
 __docformat__ = 'restructuredtext'
 
 from persistent import Persistent
